/**
 * Creates a "stack" of of all unary interceptors specified in the given `RpcOptions`.
 * Used by generated client implementations.
 * @internal
 */
export function stackUnaryInterceptors(transport, service, method, input, options) {
    var _a;
    let tail = (srv, mtd, inp, opt) => transport.unary(srv, mtd, inp, opt);
    for (const curr of ((_a = options.interceptors) !== null && _a !== void 0 ? _a : []).filter(i => i.interceptUnary).reverse()) {
        const next = tail;
        tail = (srv, mtd, inp, opt) => curr.interceptUnary(next, srv, mtd, inp, opt);
    }
    return tail(service, method, input, options);
}
/**
 * Creates a "stack" of of all server streaming interceptors specified in the given `RpcOptions`.
 * Used by generated client implementations.
 * @internal
 */
export function stackServerStreamingInterceptors(transport, service, method, input, options) {
    var _a;
    let tail = (srv, mtd, inp, opt) => transport.serverStreaming(srv, mtd, inp, opt);
    for (const curr of ((_a = options.interceptors) !== null && _a !== void 0 ? _a : []).filter(i => i.interceptServerStreaming).reverse()) {
        const next = tail;
        tail = (srv, mtd, inp, opt) => curr.interceptServerStreaming(next, srv, mtd, inp, opt);
    }
    return tail(service, method, input, options);
}
/**
 * Creates a "stack" of of all client streaming interceptors specified in the given `RpcOptions`.
 * Used by generated client implementations.
 * @internal
 */
export function stackClientStreamingInterceptors(transport, service, method, options) {
    var _a;
    let tail = (srv, mtd, opt) => transport.clientStreaming(srv, mtd, opt);
    for (const curr of ((_a = options.interceptors) !== null && _a !== void 0 ? _a : []).filter(i => i.interceptClientStreaming).reverse()) {
        const next = tail;
        tail = (srv, mtd, opt) => curr.interceptClientStreaming(next, srv, mtd, opt);
    }
    return tail(service, method, options);
}
/**
 * Creates a "stack" of of all duplex streaming interceptors specified in the given `RpcOptions`.
 * Used by generated client implementations.
 * @internal
 */
export function stackDuplexStreamingInterceptors(transport, service, method, options) {
    var _a;
    let tail = (srv, mtd, opt) => transport.duplex(srv, mtd, opt);
    for (const curr of ((_a = options.interceptors) !== null && _a !== void 0 ? _a : []).filter(i => i.interceptDuplex).reverse()) {
        const next = tail;
        tail = (srv, mtd, opt) => curr.interceptDuplex(next, srv, mtd, opt);
    }
    return tail(service, method, options);
}
//# sourceMappingURL=rpc-interceptor.js.map