import { IMessageType } from "@protobuf-ts/runtime";
import { MethodInfo, ServiceInfo } from "./reflection-info";
import { RpcStatus } from "./rpc-status";
import { RpcMetadata } from "./rpc-metadata";
export declare type RpcCancelFn = () => void;
export interface RpcCallShared<I extends object, O extends object> {
    /**
     * Reflection information about the service this call belongs to.
     * Contains the type name of the service as well as information
     * about each method.
     */
    readonly serviceInfo: ServiceInfo;
    /**
     * Reflection information about this call.
     */
    readonly methodInfo: MethodInfo<I, O>;
    /**
     * The input type of the RPC.
     */
    readonly requestType: IMessageType<I>;
    /**
     * Request headers being sent with the request.
     *
     * Request headers are provided in the `meta` property of the
     * `RpcOptions` passed to a call.
     */
    readonly requestHeaders: Readonly<RpcMetadata>;
    /**
     * The output type of the RPC.
     */
    readonly responseType: IMessageType<O>;
    /**
     * The response headers that the server sent.
     *
     * This promise will reject with a `RpcError` when the server sends an
     * error status code.
     */
    readonly responseHeaders: Promise<RpcMetadata>;
    /**
     * The response status the server replied with.
     *
     * This promise will resolve when the server has finished the request
     * successfully.
     *
     * If the server replies with an error status, this promise will
     * reject with a `RpcError`.
     */
    readonly responseStatus: Promise<RpcStatus>;
    /**
     * The trailers the server attached to the response.
     *
     * This promise will resolve when the server has finished the request
     * successfully.
     *
     * If the server replies with an error status, this promise will
     * reject with a `RpcError`.
     */
    readonly responseTrailers: Promise<RpcMetadata>;
    /**
     * Cancel this call.
     */
    cancel(): void;
}
//# sourceMappingURL=rpc-call-shared.d.ts.map